powered by
A simple function to understand the algorithm to simulate psuedo-observations from binomial distribution. It is an implementation of the algorithm given in Section 11.3.1. This function is not an alternative to the rbinom function.
Binom_Sim(size, p, N)
Size of the binomial distribution
Denotes the probability of success
The number of observations required from b(n,p)
Prabhanjan N. Tattar
rbinom
Binom_Sim(10,0.5,100)
Run the code above in your browser using DataLab