Learn R Programming

ACSWR (version 1.0.1)

LRNormalMean_UV: Likelihood ratio test for mean when variance is unknown

Description

Likelihood ratio test for mean when variance is unknown for a sample from normal distribution is setup here.

Usage

LRNormalMean_UV(x, mu0, alpha)

Arguments

x

the variable of interest

mu0

the mean value of interest

alpha

size of the LR test

Author

Prabhanjan N. Tattar

See Also

LRNormalMean_KV