Learn R Programming

ACSWR (version 1.0.1)

Poisson_Sim: Simulation for Poisson Distribution

Description

A simple function to understand the algorithm to simulate (psuedo-)observations from binomial distribution. It is an implementation of the algorithm given in Section 11.3.1 "Simulation from Discrete Distributions". This function is not an alternative to the "rpois" function.

Usage

Poisson_Sim(lambda, n)

Arguments

lambda

rate of the Poisson RV

n

required number of pseudo-observations

Author

Prabhanjan N. Tattar

See Also

rpois

Examples

Run this code
set.seed(123)
mean(Poisson_Sim(4,1000))

Run the code above in your browser using DataLab