Learn R Programming

ACSWR (version 1.0.1)

UMPExponential: Uniformly Most Powerful Test for Exponential Distribution

Description

A function is defined here which will return the uniformly most powerful test for exponential distribution. The function needs a simple use of the "qgamma" function.

Usage

UMPExponential(theta0, n, alpha)

Arguments

theta0

the parameter of interest

n

the sample size

alpha

level of the UMP test

Author

Prabhanjan N. Tattar