Learn R Programming

ACSWR (version 1.0.1)

UMPUniform: Uniformly Most Powerful Test for Uniform Sample

Description

A simple and straightforward function for obtaining the UMP test for a random sample from uniform distribution.

Usage

UMPUniform(theta0, n, alpha)

Arguments

theta0

the parameter value of interest

n

the sample size

alpha

the size of the required UMP test

Author

Prabhanjan N. Tattar

Examples

Run this code
UMPUniform(0.6,10,0.05)

Run the code above in your browser using DataLab