Learn R Programming

ACSWR (version 1.0.1)

WilsonCI: Wilson Confidence Interval

Description

The Wilson confidence interval for a sample from binomial distribution is a complex formula. This function helps the reader in easily obtaining the required confidence interval as discussed and detailed in Section 16.5.

Usage

WilsonCI(x, n, alpha)

Arguments

x

the number of successes

n

the number of trials

alpha

the confidence interval size

Author

Prabhanjan N. Tattar

Examples

Run this code
WilsonCI(x=10658,n=15000,alpha=0.05)
prop.test(x=10658,n=15000)$conf.int

Run the code above in your browser using DataLab