Learn R Programming

ACSWR (version 1.0.1)

calcium: The Calcium in Soil

Description

Kramer and Jensen (1969) collected data on three variables at 10 different locations. The variables of interest are available calcium in the soil, y1, exchangeable soil calcium, y2, and turnip green calcium, y3. The hypothesis of interest is whether the mean vector is [15.0 6.0 2.85].

Usage

data(calcium)

Arguments

Format

A data frame with 10 observations on the following 4 variables.

Location.Number

a numeric vector

y1

a numeric vector

y2

a numeric vector

y3

a numeric vector

References

Rencher, A.C. (1990-2002). Methods of Multivariate Analysis, 2e. J. Wiley.

Examples

Run this code
data(calcium)
n <- nrow(calcium)
meanx <- colMeans(calcium[,-1])
varx <- var(calcium[,-1])
mu0 <- c(15,6,2.85)
t2 <- n*t(meanx-mu0)
t2

Run the code above in your browser using DataLab