Learn R Programming

ACSWR (version 1.0.1)

girder: Strength Data Set of a Girder Experiment

Description

The shear strength of steel plate girders need to be modeled as a function of the four methods and nine girders.

Usage

data(girder)

Arguments

Format

A data frame with 9 observations on the following 5 variables.

Girder

The row names, varying from S1.1 to S4.2, represent the nine type of girders, S1.1 S1.2 S2.1 S2.2 S3.1 S3.2 S4.1 S4.2 S5.1

Aarau

one of the four methods of preparation of the steel plates

Karisruhe

one of the four methods of preparation of the steel plates

Lehigh

one of the four methods of preparation of the steel plates

Cardiff

one of the four methods of preparation of the steel plates

References

Wu, C.F.J. and M. Hamada (2000-9). Experiments: Planning, Analysis, and Parameter Design Optimization, 2e. J. Wiley.

Examples

Run this code
data(girder)
girder
boxplot(girder[,2:5])

Run the code above in your browser using DataLab