Learn R Programming

ACSWR (version 1.0.1)

memory: Memory Recall Times

Description

A test had been conducted with the purpose of investigating if people recollect pleasant memories associated with a word earlier than some unpleasant memory related with the same word. The word is flashed on the screen and the time an individual takes to respond via keyboard is recorded for both type of the memories.

Usage

data(memory)

Arguments

Format

A data frame with 20 observations on the following 2 variables.

Pleasant.memory

time to recollect pleasant memory

Unpleasant.memory

time to recollect unpleasant memory

References

Dunn, and Master. (1982). Obtained from

https://www.open.edu/openlearn/science-maths-technology/mathematics-statistics/interpreting-data-boxplots-and-tables/content-section-2.6/?printable=1#tbl001_005

Examples

Run this code
data(memory)
lapply(memory,fivenum)
lapply(memory,mad)
lapply(memory,IQR)

Run the code above in your browser using DataLab