Learn R Programming

ACSWR (version 1.0.1)

pareto_quantile: Quantile of Pareto RV

Description

A simple function is given here which returns the quantiles for a Pareto RV. A more efficient implementation is obtainable in the function "qpareto" from the "VGAM" package.

Usage

pareto_quantile(p, scale, shape)

Arguments

p

the percentiles required

scale

scale of Pareto RV

shape

shape of Pareto RV

Author

Prabhanjan N. Tattar

See Also

VGAM::qpareto

Examples

Run this code
pareto_quantile(c(0.05,0.95),scale=10000,shape=10)

Run the code above in your browser using DataLab