Learn R Programming

ACSWR (version 1.0.1)

reaction: Chemical Reaction Experiment

Description

For a chemical reaction experiment, the blocks arise due to the Batch number, Catalyst of different types form the treatments, and the reaction time is the output. Due to a restriction, all the catalysts cannot be analysed within each batch and hence we need to look at the BIBD model.

Usage

data("reaction")

Arguments

Format

A data frame with 16 observations on the following 3 variables.

Catalyst

different types forming the treatments

Batch

batch number

Reaction

reaction time

Examples

Run this code
data(reaction)

Run the code above in your browser using DataLab