Learn R Programming

ACSWR (version 1.0.1)

swiss: Forged Swiss Bank Notes

Description

The swiss data set consists of measurements on the width of bottom margin and image diagonal length for forged and real notes. Histogram smoothing method is applied to understand the width of bottom margins for the forged notes.

Usage

data(swiss)

Arguments

Format

A data frame with 100 observations on the following 4 variables.

Bottforg

bottom margin of forged notes

Diagforg

diagonal margin of forged notes

Bottreal

bottom margin of real notes

Diagreal

diagonal margin of real notes

References

Simonoff, J.S. (1996). Smoothing Methods in Statistics. Springer.

Examples

Run this code
data(swiss)
par(mfrow=c(1,3))
hist(swiss$Bottforg,breaks=28,probability=TRUE,col=0,ylim=c(0,.5),
  xlab="Margin width (mm)",ylab="Density")
hist(swiss$Bottforg,breaks=12,probability=TRUE,col=0,ylim=c(0,.5),
  xlab="Margin width (mm)",ylab="Density")
hist(swiss$Bottforg,breaks=6,probability=TRUE,col=0,ylim=c(0,.5),
  xlab="Margin width (mm)",ylab="Density")

Run the code above in your browser using DataLab