Water
samples from four cities are collected and their physico-chemical properties for ten variables, such as pH, Conductivity, Dissolution, etc., are measured. We would then like to test if the properties are same across the four cities and in which case a same water treatment approach can be adopted across the cities.