powered by
The Wilson confidence interval for a sample from binomial distribution is a complex formula. This function helps the reader in easily obtaining the required confidence interval as discussed and detailed in Section 16.5.
WilsonCI(x, n, alpha)
the number of successes
the number of trials
the confidence interval size
Prabhanjan N. Tattar
WilsonCI(x=10658,n=15000,alpha=0.05) prop.test(x=10658,n=15000)$conf.int
Run the code above in your browser using DataLab