powered by
A simple function is given here which returns the quantiles for a Pareto RV. A more efficient implementation is obtainable in the function "qpareto" from the "VGAM" package.
pareto_quantile(p, scale, shape)
the percentiles required
scale of Pareto RV
shape of Pareto RV
Prabhanjan N. Tattar
VGAM::qpareto
pareto_quantile(c(0.05,0.95),scale=10000,shape=10)
Run the code above in your browser using DataLab